src/pyams_content/component/paragraph/zmi/header.py
changeset 406 5527bc086216
parent 283 9139536eab90
child 407 0ef5de2d5674
--- a/src/pyams_content/component/paragraph/zmi/header.py	Thu Feb 22 10:15:00 2018 +0100
+++ b/src/pyams_content/component/paragraph/zmi/header.py	Thu Feb 22 12:00:05 2018 +0100
@@ -17,7 +17,7 @@
 
 # import interfaces
 from pyams_content.component.paragraph.interfaces import IParagraphContainerTarget, IParagraphContainer, \
-    IParagraphSummary
+    IParagraphPreview
 from pyams_content.component.paragraph.interfaces.header import IHeaderParagraph
 from pyams_content.component.paragraph.zmi.interfaces import IParagraphInnerEditor, IParagraphContainerView
 from pyams_content.interfaces import MANAGE_CONTENT_PERMISSION
@@ -140,13 +140,13 @@
 
 
 #
 # HTML paragraph summary
 #
 
-@adapter_config(context=(IHeaderParagraph, IPyAMSLayer), provides=IParagraphSummary)
-@template_config(template='templates/header-summary.pt', layer=IPyAMSLayer)
-class HeaderParagraphSummary(BaseContentProvider):
-    """Header paragraph renderer"""
+@adapter_config(context=(IHeaderParagraph, IPyAMSLayer), provides=IParagraphPreview)
+@template_config(template='templates/header-preview.pt', layer=IPyAMSLayer)
+class HeaderParagraphPreview(BaseContentProvider):
+    """Header paragraph preview"""
 
     language = None
@@ -140,13 +140,13 @@
 
 #
-# HTML paragraph summary
+# HTML paragraph preview
 #
 